summaryrefslogtreecommitdiffstats
path: root/kicker/menuext
diff options
context:
space:
mode:
Diffstat (limited to 'kicker/menuext')
-rw-r--r--kicker/menuext/find/findmenu.cpp12
-rw-r--r--kicker/menuext/find/findmenu.h4
-rw-r--r--kicker/menuext/kate/katesessionmenu.cpp24
-rw-r--r--kicker/menuext/kate/katesessionmenu.h6
-rw-r--r--kicker/menuext/kdeprint/print_mnu.cpp14
-rw-r--r--kicker/menuext/kdeprint/print_mnu.h2
-rw-r--r--kicker/menuext/konq-profiles/konqy_menu.cpp20
-rw-r--r--kicker/menuext/konq-profiles/konqy_menu.h6
-rw-r--r--kicker/menuext/konsole/konsole_mnu.cpp68
-rw-r--r--kicker/menuext/konsole/konsole_mnu.h12
-rw-r--r--kicker/menuext/konsole/konsolebookmarkhandler.cpp48
-rw-r--r--kicker/menuext/konsole/konsolebookmarkhandler.h24
-rw-r--r--kicker/menuext/konsole/konsolebookmarkmenu.cpp38
-rw-r--r--kicker/menuext/konsole/konsolebookmarkmenu.h8
-rw-r--r--kicker/menuext/prefmenu/prefmenu.cpp70
-rw-r--r--kicker/menuext/prefmenu/prefmenu.h30
-rw-r--r--kicker/menuext/recentdocs/recentdocsmenu.cpp30
-rw-r--r--kicker/menuext/recentdocs/recentdocsmenu.h10
-rw-r--r--kicker/menuext/remote/remotemenu.cpp38
-rw-r--r--kicker/menuext/remote/remotemenu.h8
-rw-r--r--kicker/menuext/system/systemmenu.cpp18
-rw-r--r--kicker/menuext/system/systemmenu.h8
-rw-r--r--kicker/menuext/tom/tom.cc224
-rw-r--r--kicker/menuext/tom/tom.h48
24 files changed, 385 insertions, 385 deletions
diff --git a/kicker/menuext/find/findmenu.cpp b/kicker/menuext/find/findmenu.cpp
index fc3ae12a6..24020e0c2 100644
--- a/kicker/menuext/find/findmenu.cpp
+++ b/kicker/menuext/find/findmenu.cpp
@@ -31,8 +31,8 @@
K_EXPORT_KICKER_MENUEXT( find, FindMenu )
-FindMenu::FindMenu( QWidget *parent, const char *name,
- const QStringList &/*args*/)
+FindMenu::FindMenu( TQWidget *parent, const char *name,
+ const TQStringList &/*args*/)
: KPanelMenu( "", parent, name )
{
}
@@ -44,19 +44,19 @@ FindMenu::~FindMenu()
void FindMenu::initialize()
{
- QStringList list = KGlobal::dirs()->findAllResources( "data", "kicker/menuext/find/*.desktop", false, true );
+ TQStringList list = KGlobal::dirs()->findAllResources( "data", "kicker/menuext/find/*.desktop", false, true );
list.sort();
int id = 0;
mConfigList.clear();
- for ( QStringList::ConstIterator it = list.begin(); it != list.end(); ++it ) {
+ for ( TQStringList::ConstIterator it = list.begin(); it != list.end(); ++it ) {
KSimpleConfig config( *it, true );
config.setDesktopGroup();
mConfigList.append( *it );
- QString text = config.readEntry( "Name" );
+ TQString text = config.readEntry( "Name" );
insertItem( SmallIconSet( config.readEntry( "Icon" ) ), text, id );
id++;
@@ -65,7 +65,7 @@ void FindMenu::initialize()
void FindMenu::slotExec( int pos )
{
- QString app = mConfigList[ pos ];
+ TQString app = mConfigList[ pos ];
kapp->propagateSessionManager();
diff --git a/kicker/menuext/find/findmenu.h b/kicker/menuext/find/findmenu.h
index 2297c4dff..09bd06aca 100644
--- a/kicker/menuext/find/findmenu.h
+++ b/kicker/menuext/find/findmenu.h
@@ -33,7 +33,7 @@ class FindMenu : public KPanelMenu
Q_OBJECT
public:
- FindMenu( QWidget* parent, const char* name, const QStringList &/*args*/ );
+ FindMenu( TQWidget* parent, const char* name, const TQStringList &/*args*/ );
~FindMenu();
protected slots:
@@ -41,7 +41,7 @@ class FindMenu : public KPanelMenu
void slotExec( int );
private:
- QStringList mConfigList;
+ TQStringList mConfigList;
};
#endif
diff --git a/kicker/menuext/kate/katesessionmenu.cpp b/kicker/menuext/kate/katesessionmenu.cpp
index 63cee8106..584a345aa 100644
--- a/kicker/menuext/kate/katesessionmenu.cpp
+++ b/kicker/menuext/kate/katesessionmenu.cpp
@@ -32,18 +32,18 @@
#include <ksimpleconfig.h>
#include <kstandarddirs.h>
-#include <qvalidator.h>
+#include <tqvalidator.h>
-class Validator : public QValidator {
+class Validator : public TQValidator {
public:
- Validator( QObject *parent ) : QValidator( parent, 0 ) {}
+ Validator( TQObject *parent ) : TQValidator( parent, 0 ) {}
~Validator() {}
- virtual QValidator::State validate( QString &, int & ) const { return QValidator::Acceptable; }
+ virtual TQValidator::State validate( TQString &, int & ) const { return TQValidator::Acceptable; }
};
K_EXPORT_KICKER_MENUEXT(kate, KateSessionMenu)
-KateSessionMenu::KateSessionMenu( QWidget *parent, const char *name, const QStringList& )
+KateSessionMenu::KateSessionMenu( TQWidget *parent, const char *name, const TQStringList& )
: KPanelMenu( parent, name ),
m_parent( parent )
{
@@ -76,8 +76,8 @@ void KateSessionMenu::initialize()
insertSeparator();
- QStringList list = KGlobal::dirs()->findAllResources( "data", "kate/sessions/*.katesession", false, true);
- for (QStringList::ConstIterator it = list.begin(); it != list.end(); ++it)
+ TQStringList list = KGlobal::dirs()->findAllResources( "data", "kate/sessions/*.katesession", false, true);
+ for (TQStringList::ConstIterator it = list.begin(); it != list.end(); ++it)
{
KSimpleConfig config( *it, true );
config.setGroup( "General" );
@@ -86,14 +86,14 @@ void KateSessionMenu::initialize()
m_sessions.sort();
- for ( QStringList::ConstIterator it1 = m_sessions.begin(); it1 != m_sessions.end(); ++it1 )
+ for ( TQStringList::ConstIterator it1 = m_sessions.begin(); it1 != m_sessions.end(); ++it1 )
{
insertItem( *it1, id++ );
}
// means for updating, to let the user manually update if he/she added new sessions.
insertSeparator();
- insertItem( SmallIconSet("reload"), i18n("Reload Session List"), this, SLOT(reinitialize()) );
+ insertItem( SmallIconSet("reload"), i18n("Reload Session List"), this, TQT_SLOT(reinitialize()) );
}
void KateSessionMenu::slotExec( int id )
@@ -101,7 +101,7 @@ void KateSessionMenu::slotExec( int id )
if ( id < 0 )
return;
- QStringList args;
+ TQStringList args;
if ( id > 0 )
args << "--start";
@@ -109,9 +109,9 @@ void KateSessionMenu::slotExec( int id )
if ( id == 1 )
{
bool ok (false);
- QString name = KInputDialog::getText( i18n("Session Name"),
+ TQString name = KInputDialog::getText( i18n("Session Name"),
i18n("Please enter a name for the new session"),
- QString::null,
+ TQString::null,
&ok, 0, 0, new Validator( m_parent ) );
if ( ! ok )
return;
diff --git a/kicker/menuext/kate/katesessionmenu.h b/kicker/menuext/kate/katesessionmenu.h
index ea78bf6ba..3d5519496 100644
--- a/kicker/menuext/kate/katesessionmenu.h
+++ b/kicker/menuext/kate/katesessionmenu.h
@@ -26,7 +26,7 @@
class KateSessionMenu : public KPanelMenu {
Q_OBJECT
public:
- KateSessionMenu( QWidget *parent=0, const char *name=0, const QStringList& /*args*/=QStringList() );
+ KateSessionMenu( TQWidget *parent=0, const char *name=0, const TQStringList& /*args*/=TQStringList() );
~KateSessionMenu();
public slots:
@@ -36,8 +36,8 @@ class KateSessionMenu : public KPanelMenu {
virtual void slotExec( int id );
private:
- QStringList m_sessions;
- QWidget *m_parent;
+ TQStringList m_sessions;
+ TQWidget *m_parent;
};
#endif // _KateSessionMenu_h_
diff --git a/kicker/menuext/kdeprint/print_mnu.cpp b/kicker/menuext/kdeprint/print_mnu.cpp
index 8b2679432..eb2dbd8ab 100644
--- a/kicker/menuext/kdeprint/print_mnu.cpp
+++ b/kicker/menuext/kdeprint/print_mnu.cpp
@@ -28,7 +28,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <kapplication.h>
#include <krun.h>
#include <kdeprint/kmmanager.h>
-#include <qregexp.h>
+#include <tqregexp.h>
K_EXPORT_KICKER_MENUEXT(kdeprint, PrintMenu)
@@ -40,7 +40,7 @@ K_EXPORT_KICKER_MENUEXT(kdeprint, PrintMenu)
#define KPRINTER_ID 5
#define PRINTER_LIST_ID 10
-PrintMenu::PrintMenu(QWidget *parent, const char *name, const QStringList & /*args*/)
+PrintMenu::PrintMenu(TQWidget *parent, const char *name, const TQStringList & /*args*/)
: KPanelMenu("", parent, name)
{
static bool kdeprintIconsInitialized = false;
@@ -75,11 +75,11 @@ void PrintMenu::initialize()
insertItem(SmallIconSet("fileprint"), i18n("Print File..."), KPRINTER_ID);
// printer list
- QPtrList<KMPrinter> *l = KMManager::self()->printerList();
+ TQPtrList<KMPrinter> *l = KMManager::self()->printerList();
if (l && !l->isEmpty())
{
bool separatorInserted = false;
- QPtrListIterator<KMPrinter> it(*l);
+ TQPtrListIterator<KMPrinter> it(*l);
for (; it.current(); ++it)
{
// no special, implicit or pure instances
@@ -106,10 +106,10 @@ void PrintMenu::slotExec(int ID)
kapp->kdeinitExec("kaddprinterwizard");
break;
case KDEPRINT_SETTINGS_ID:
- kapp->kdeinitExec("kaddprinterwizard", QStringList("--kdeconfig"));
+ kapp->kdeinitExec("kaddprinterwizard", TQStringList("--kdeconfig"));
break;
case CONFIG_SERVER_ID:
- kapp->kdeinitExec("kaddprinterwizard", QStringList("--serverconfig"));
+ kapp->kdeinitExec("kaddprinterwizard", TQStringList("--serverconfig"));
break;
case PRINT_MANAGER_ID:
KRun::runCommand("kcmshell kde-printers.desktop");
@@ -123,7 +123,7 @@ void PrintMenu::slotExec(int ID)
default:
{
// start kjobviewer
- QStringList args;
+ TQStringList args;
args << "--show" << "-d" << text(ID).remove('&');
kapp->kdeinitExec("kjobviewer", args);
}
diff --git a/kicker/menuext/kdeprint/print_mnu.h b/kicker/menuext/kdeprint/print_mnu.h
index a80da4be2..da795c039 100644
--- a/kicker/menuext/kdeprint/print_mnu.h
+++ b/kicker/menuext/kdeprint/print_mnu.h
@@ -32,7 +32,7 @@ class PrintMenu : public KPanelMenu, public KPReloadObject
Q_OBJECT
public:
- PrintMenu(QWidget *parent, const char *name, const QStringList & /*args*/);
+ PrintMenu(TQWidget *parent, const char *name, const TQStringList & /*args*/);
~PrintMenu();
protected slots:
diff --git a/kicker/menuext/konq-profiles/konqy_menu.cpp b/kicker/menuext/konq-profiles/konqy_menu.cpp
index 3ac09e050..4010bace7 100644
--- a/kicker/menuext/konq-profiles/konqy_menu.cpp
+++ b/kicker/menuext/konq-profiles/konqy_menu.cpp
@@ -31,12 +31,12 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <kio/global.h>
#include <ksimpleconfig.h>
-#include <qregexp.h>
-#include <qfileinfo.h>
+#include <tqregexp.h>
+#include <tqfileinfo.h>
K_EXPORT_KICKER_MENUEXT(konqueror, KonquerorProfilesMenu)
-KonquerorProfilesMenu::KonquerorProfilesMenu(QWidget *parent, const char *name, const QStringList & /*args*/)
+KonquerorProfilesMenu::KonquerorProfilesMenu(TQWidget *parent, const char *name, const TQStringList & /*args*/)
: KPanelMenu("", parent, name)
{
static bool kdeprintIconsInitialized = false;
@@ -55,16 +55,16 @@ void KonquerorProfilesMenu::initialize()
if (initialized()) clear();
setInitialized(true);
- QStringList profiles = KGlobal::dirs()->findAllResources( "data", "konqueror/profiles/*", false, true );
+ TQStringList profiles = KGlobal::dirs()->findAllResources( "data", "konqueror/profiles/*", false, true );
m_profiles.resize(profiles.count());
int id=1;
- QStringList::ConstIterator pEnd = profiles.end();
- for (QStringList::ConstIterator pIt = profiles.begin(); pIt != pEnd; ++pIt )
+ TQStringList::ConstIterator pEnd = profiles.end();
+ for (TQStringList::ConstIterator pIt = profiles.begin(); pIt != pEnd; ++pIt )
{
- QFileInfo info( *pIt );
- QString profileName = KIO::decodeFileName( info.baseName() );
- QString niceName=profileName;
+ TQFileInfo info( *pIt );
+ TQString profileName = KIO::decodeFileName( info.baseName() );
+ TQString niceName=profileName;
KSimpleConfig cfg( *pIt, true );
if ( cfg.hasGroup( "Profile" ) )
{
@@ -81,7 +81,7 @@ void KonquerorProfilesMenu::initialize()
void KonquerorProfilesMenu::slotExec(int id)
{
- QStringList args;
+ TQStringList args;
args<<"--profile"<<m_profiles[id-1];
kapp->kdeinitExec("konqueror", args);
}
diff --git a/kicker/menuext/konq-profiles/konqy_menu.h b/kicker/menuext/konq-profiles/konqy_menu.h
index f47b026ee..ba3bb19f7 100644
--- a/kicker/menuext/konq-profiles/konqy_menu.h
+++ b/kicker/menuext/konq-profiles/konqy_menu.h
@@ -26,14 +26,14 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <kpanelmenu.h>
-#include <qvaluevector.h>
+#include <tqvaluevector.h>
class KonquerorProfilesMenu : public KPanelMenu
{
Q_OBJECT
public:
- KonquerorProfilesMenu(QWidget *parent, const char *name, const QStringList & /*args*/);
+ KonquerorProfilesMenu(TQWidget *parent, const char *name, const TQStringList & /*args*/);
~KonquerorProfilesMenu();
protected slots:
@@ -43,7 +43,7 @@ class KonquerorProfilesMenu : public KPanelMenu
protected:
void reload();
- QValueVector<QString> m_profiles;
+ TQValueVector<TQString> m_profiles;
};
diff --git a/kicker/menuext/konsole/konsole_mnu.h b/kicker/menuext/konsole/konsole_mnu.h
index 988764124..e64c53212 100644
--- a/kicker/menuext/konsole/konsole_mnu.h
+++ b/kicker/menuext/konsole/konsole_mnu.h
@@ -24,7 +24,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#ifndef _konsole_mnu_h_
#define _konsole_mnu_h_
-#include <qvaluevector.h>
+#include <tqvaluevector.h>
#include <kpanelmenu.h>
#include <klibloader.h>
@@ -38,7 +38,7 @@ class KonsoleMenu : public KPanelMenu/*, public KPReloadObject*/
Q_OBJECT
public:
- KonsoleMenu(QWidget *parent, const char *name, const QStringList& /* args */);
+ KonsoleMenu(TQWidget *parent, const char *name, const TQStringList& /* args */);
~KonsoleMenu();
KURL baseURL() const;
@@ -47,13 +47,13 @@ protected slots:
void slotExec(int id);
void launchProfile(int id);
void initialize();
- void newSession(const QString& sURL, const QString& title);
+ void newSession(const TQString& sURL, const TQString& title);
private:
- QStringList sessionList;
- QStringList screenList;
- QValueVector<QString> m_profiles;
+ TQStringList sessionList;
+ TQStringList screenList;
+ TQValueVector<TQString> m_profiles;
KPopupMenu* m_profileMenu;
KPopupMenu* m_bookmarksSession;
diff --git a/kicker/menuext/konsole/konsolebookmarkhandler.cpp b/kicker/menuext/konsole/konsolebookmarkhandler.cpp
index c9f8e2806..46967b54c 100644
--- a/kicker/menuext/konsole/konsolebookmarkhandler.cpp
+++ b/kicker/menuext/konsole/konsolebookmarkhandler.cpp
@@ -3,7 +3,7 @@
#include <stdio.h>
#include <stdlib.h>
-#include <qtextstream.h>
+#include <tqtextstream.h>
#include <kbookmarkimporter.h>
#include <kmimetype.h>
@@ -16,20 +16,20 @@
#include "konsolebookmarkhandler.h"
KonsoleBookmarkHandler::KonsoleBookmarkHandler( KonsoleMenu *konsole, bool )
- : QObject( konsole, "KonsoleBookmarkHandler" ),
+ : TQObject( konsole, "KonsoleBookmarkHandler" ),
KBookmarkOwner(),
m_konsole( konsole ),
m_importStream( 0L )
{
m_menu = new KPopupMenu( konsole, "bookmark menu" );
- QString file = locate( "data", "konsole/bookmarks.xml" );
+ TQString file = locate( "data", "konsole/bookmarks.xml" );
if ( file.isEmpty() )
file = locateLocal( "data", "konsole/bookmarks.xml" );
// import old bookmarks
if ( !KStandardDirs::exists( file ) ) {
- QString oldFile = locate( "data", "kfile/bookmarks.html" );
+ TQString oldFile = locate( "data", "kfile/bookmarks.html" );
if ( !oldFile.isEmpty() )
importOldBookmarks( oldFile, file );
}
@@ -38,20 +38,20 @@ KonsoleBookmarkHandler::KonsoleBookmarkHandler( KonsoleMenu *konsole, bool )
manager->setUpdate( true );
manager->setShowNSBookmarks( false );
- connect( manager, SIGNAL( changed(const QString &, const QString &) ),
- SLOT( slotBookmarksChanged(const QString &, const QString &) ) );
+ connect( manager, TQT_SIGNAL( changed(const TQString &, const TQString &) ),
+ TQT_SLOT( slotBookmarksChanged(const TQString &, const TQString &) ) );
m_bookmarkMenu = new KonsoleBookmarkMenu( manager, this, m_menu,
NULL, false, /*Not toplevel*/
false /*No 'Add Bookmark'*/ );
}
-QString KonsoleBookmarkHandler::currentURL() const
+TQString KonsoleBookmarkHandler::currentURL() const
{
return m_konsole->baseURL().url();
}
-void KonsoleBookmarkHandler::importOldBookmarks( const QString& path,
- const QString& destinationPath )
+void KonsoleBookmarkHandler::importOldBookmarks( const TQString& path,
+ const TQString& destinationPath )
{
KSaveFile file( destinationPath );
if ( file.status() != 0 )
@@ -62,13 +62,13 @@ void KonsoleBookmarkHandler::importOldBookmarks( const QString& path,
KNSBookmarkImporter importer( path );
connect( &importer,
- SIGNAL( newBookmark( const QString&, const QCString&, const QString& )),
- SLOT( slotNewBookmark( const QString&, const QCString&, const QString& )));
+ TQT_SIGNAL( newBookmark( const TQString&, const TQCString&, const TQString& )),
+ TQT_SLOT( slotNewBookmark( const TQString&, const TQCString&, const TQString& )));
connect( &importer,
- SIGNAL( newFolder( const QString&, bool, const QString& )),
- SLOT( slotNewFolder( const QString&, bool, const QString& )));
- connect( &importer, SIGNAL( newSeparator() ), SLOT( newSeparator() ));
- connect( &importer, SIGNAL( endMenu() ), SLOT( endMenu() ));
+ TQT_SIGNAL( newFolder( const TQString&, bool, const TQString& )),
+ TQT_SLOT( slotNewFolder( const TQString&, bool, const TQString& )));
+ connect( &importer, TQT_SIGNAL( newSeparator() ), TQT_SLOT( newSeparator() ));
+ connect( &importer, TQT_SIGNAL( endMenu() ), TQT_SLOT( endMenu() ));
importer.parseNSBookmarks( false );
@@ -78,24 +78,24 @@ void KonsoleBookmarkHandler::importOldBookmarks( const QString& path,
m_importStream = 0L;
}
-void KonsoleBookmarkHandler::slotNewBookmark( const QString& /*text*/,
- const QCString& url,
- const QString& additionalInfo )
+void KonsoleBookmarkHandler::slotNewBookmark( const TQString& /*text*/,
+ const TQCString& url,
+ const TQString& additionalInfo )
{
*m_importStream << "<bookmark icon=\"" << KMimeType::iconForURL( KURL( url ) );
- *m_importStream << "\" href=\"" << QString::fromUtf8(url) << "\">\n";
- *m_importStream << "<title>" << (additionalInfo.isEmpty() ? QString::fromUtf8(url) : additionalInfo) << "</title>\n</bookmark>\n";
+ *m_importStream << "\" href=\"" << TQString::fromUtf8(url) << "\">\n";
+ *m_importStream << "<title>" << (additionalInfo.isEmpty() ? TQString::fromUtf8(url) : additionalInfo) << "</title>\n</bookmark>\n";
}
-void KonsoleBookmarkHandler::slotNewFolder( const QString& text, bool /*open*/,
- const QString& /*additionalInfo*/ )
+void KonsoleBookmarkHandler::slotNewFolder( const TQString& text, bool /*open*/,
+ const TQString& /*additionalInfo*/ )
{
*m_importStream << "<folder icon=\"bookmark_folder\">\n<title=\"";
*m_importStream << text << "\">\n";
}
-void KonsoleBookmarkHandler::slotBookmarksChanged( const QString &,
- const QString & )
+void KonsoleBookmarkHandler::slotBookmarksChanged( const TQString &,
+ const TQString & )
{
// This is called when someone changes bookmarks in konsole....
m_bookmarkMenu->slotBookmarksChanged("");
diff --git a/kicker/menuext/konsole/konsolebookmarkhandler.h b/kicker/menuext/konsole/konsolebookmarkhandler.h
index b22f0d03d..eed2c00d6 100644
--- a/kicker/menuext/konsole/konsolebookmarkhandler.h
+++ b/kicker/menuext/konsole/konsolebookmarkhandler.h
@@ -12,42 +12,42 @@ class KPopupMenu;
class KonsoleBookmarkMenu;
class KonsoleMenu;
-class KonsoleBookmarkHandler : public QObject, public KBookmarkOwner
+class KonsoleBookmarkHandler : public TQObject, public KBookmarkOwner
{
Q_OBJECT
public:
KonsoleBookmarkHandler( KonsoleMenu *konsole, bool toplevel );
- QPopupMenu * popupMenu();
+ TQPopupMenu * popupMenu();
// KBookmarkOwner interface:
- virtual void openBookmarkURL( const QString& url, const QString& title )
+ virtual void openBookmarkURL( const TQString& url, const TQString& title )
{ emit openURL( url, title ); }
- virtual QString currentURL() const;
+ virtual TQString currentURL() const;
KPopupMenu *menu() const { return m_menu; }
signals:
- void openURL( const QString& url, const QString& title );
+ void openURL( const TQString& url, const TQString& title );
private slots:
// for importing
- void slotNewBookmark( const QString& text, const QCString& url,
- const QString& additionalInfo );
- void slotNewFolder( const QString& text, bool open,
- const QString& additionalInfo );
- void slotBookmarksChanged( const QString &, const QString & caller );
+ void slotNewBookmark( const TQString& text, const TQCString& url,
+ const TQString& additionalInfo );
+ void slotNewFolder( const TQString& text, bool open,
+ const TQString& additionalInfo );
+ void slotBookmarksChanged( const TQString &, const TQString & caller );
void newSeparator();
void endFolder();
private:
- void importOldBookmarks( const QString& path, const QString& destinationPath );
+ void importOldBookmarks( const TQString& path, const TQString& destinationPath );
KonsoleMenu *m_konsole;
KPopupMenu *m_menu;
KonsoleBookmarkMenu *m_bookmarkMenu;
- QTextStream *m_importStream;
+ TQTextStream *m_importStream;
protected:
virtual void virtual_hook( int id, void* data );
diff --git a/kicker/menuext/konsole/konsolebookmarkmenu.h b/kicker/menuext/konsole/konsolebookmarkmenu.h
index 65e87f0f5..681236708 100644
--- a/kicker/menuext/konsole/konsolebookmarkmenu.h
+++ b/kicker/menuext/konsole/konsolebookmarkmenu.h
@@ -1,9 +1,9 @@
#ifndef KONSOLEBOOKMARKMENU_H
#define KONSOLEBOOKMARKMENU_H
-#include <qptrlist.h>
-#include <qptrstack.h>
-#include <qobject.h>
+#include <tqptrlist.h>
+#include <tqptrstack.h>
+#include <tqobject.h>
#include <sys/types.h>
#include <kbookmark.h>
#include <kbookmarkmenu.h>
@@ -29,7 +29,7 @@ public:
KonsoleBookmarkMenu( KBookmarkManager* mgr,
KonsoleBookmarkHandler * _owner, KPopupMenu * _parentMenu,
KActionCollection *collec, bool _isRoot,
- bool _add = true, const QString & parentAddress = "");
+ bool _add = true, const TQString & parentAddress = "");
void fillBookmarkMenu();
diff --git a/kicker/menuext/prefmenu/prefmenu.cpp b/kicker/menuext/prefmenu/prefmenu.cpp
index dd157d2cb..0c072e026 100644
--- a/kicker/menuext/prefmenu/prefmenu.cpp
+++ b/kicker/menuext/prefmenu/prefmenu.cpp
@@ -21,8 +21,8 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
******************************************************************/
-#include <qcursor.h>
-#include <qtimer.h>
+#include <tqcursor.h>
+#include <tqtimer.h>
#include <kapplication.h>
#include <kglobal.h>
@@ -43,28 +43,28 @@ K_EXPORT_KICKER_MENUEXT(prefmenu, PrefMenu)
const int idStart = 4242;
-PrefMenu::PrefMenu(QWidget *parent,
+PrefMenu::PrefMenu(TQWidget *parent,
const char *name,
- const QStringList &/*args*/)
+ const TQStringList &/*args*/)
: KPanelMenu(i18n("Settings"), parent, name),
m_clearOnClose(false)
{
}
-PrefMenu::PrefMenu(const QString& label,
- const QString& root,
- QWidget *parent)
+PrefMenu::PrefMenu(const TQString& label,
+ const TQString& root,
+ TQWidget *parent)
: KPanelMenu(label, parent),
m_clearOnClose(false),
m_root(root)
{
m_subMenus.setAutoDelete(true);
- connect(KSycoca::self(), SIGNAL(databaseChanged()),
- this, SLOT(clearOnClose()));
+ connect(KSycoca::self(), TQT_SIGNAL(databaseChanged()),
+ this, TQT_SLOT(clearOnClose()));
- connect(this, SIGNAL(aboutToHide()),
- this, SLOT(aboutToClose()));
+ connect(this, TQT_SIGNAL(aboutToHide()),
+ this, TQT_SLOT(aboutToClose()));
}
PrefMenu::~PrefMenu()
@@ -74,11 +74,11 @@ PrefMenu::~PrefMenu()
void PrefMenu::insertMenuItem(KService::Ptr& s,
int nId,
int nIndex,
- const QStringList *suppressGenericNames)
+ const TQStringList *suppressGenericNames)
{
- QString serviceName = s->name();
+ TQString serviceName = s->name();
// add comment
- QString comment = s->genericName();
+ TQString comment = s->genericName();
if (!comment.isEmpty())
{
if (KickerSettings::menuEntryFormat() == KickerSettings::NameAndDescription)
@@ -86,12 +86,12 @@ void PrefMenu::insertMenuItem(KService::Ptr& s,
if (!suppressGenericNames ||
!suppressGenericNames->contains(s->untranslatedGenericName()))
{
- serviceName = QString("%1 (%2)").arg(serviceName).arg(comment);
+ serviceName = TQString("%1 (%2)").arg(serviceName).arg(comment);
}
}
else if (KickerSettings::menuEntryFormat() == KickerSettings::DescriptionAndName)
{
- serviceName = QString("%1 (%2)").arg(comment).arg(serviceName);
+ serviceName = TQString("%1 (%2)").arg(comment).arg(serviceName);
}
else if (KickerSettings::menuEntryFormat() == KickerSettings::DescriptionOnly)
{
@@ -126,13 +126,13 @@ void PrefMenu::insertMenuItem(KService::Ptr& s,
m_entryMap.insert(newId, static_cast<KSycocaEntry*>(s));
}
-void PrefMenu::mousePressEvent(QMouseEvent * ev)
+void PrefMenu::mousePressEvent(TQMouseEvent * ev)
{
m_dragStartPos = ev->pos();
KPanelMenu::mousePressEvent(ev);
}
-void PrefMenu::mouseMoveEvent(QMouseEvent * ev)
+void PrefMenu::mouseMoveEvent(TQMouseEvent * ev)
{
KPanelMenu::mouseMoveEvent(ev);
@@ -141,8 +141,8 @@ void PrefMenu::mouseMoveEvent(QMouseEvent * ev)
return;
}
- QPoint p = ev->pos() - m_dragStartPos;
- if (p.manhattanLength() <= QApplication::startDragDistance())
+ TQPoint p = ev->pos() - m_dragStartPos;
+ if (p.manhattanLength() <= TQApplication::startDragDistance())
{
return;
}
@@ -163,7 +163,7 @@ void PrefMenu::mouseMoveEvent(QMouseEvent * ev)
KSycocaEntry * e = m_entryMap[id];
- QPixmap icon;
+ TQPixmap icon;
KURL url;
switch (e->sycocaType())
@@ -171,7 +171,7 @@ void PrefMenu::mouseMoveEvent(QMouseEvent * ev)
case KST_KService:
{
icon = static_cast<KService *>(e)->pixmap(KIcon::Small);
- QString filePath = static_cast<KService *>(e)->desktopEntryPath();
+ TQString filePath = static_cast<KService *>(e)->desktopEntryPath();
if (filePath[0] != '/')
{
filePath = locate("apps", filePath);
@@ -198,17 +198,17 @@ void PrefMenu::mouseMoveEvent(QMouseEvent * ev)
// If the path to the desktop file is relative, try to get the full
// path from KStdDirs.
KURLDrag *d = new KURLDrag(KURL::List(url), this);
- connect(d, SIGNAL(destroyed()), this, SLOT(dragObjectDestroyed()));
+ connect(d, TQT_SIGNAL(destroyed()), this, TQT_SLOT(dragObjectDestroyed()));
d->setPixmap(icon);
d->dragCopy();
// Set the startposition outside the panel, so there is no drag initiated
// when we use drag and click to select items. A drag is only initiated when
// you click to open the menu, and then press and drag an item.
- m_dragStartPos = QPoint(-1,-1);
+ m_dragStartPos = TQPoint(-1,-1);
}
-void PrefMenu::dragEnterEvent(QDragEnterEvent *event)
+void PrefMenu::dragEnterEvent(TQDragEnterEvent *event)
{
// Set the DragObject's target to this widget. This is needed because the
// widget doesn't accept drops, but we want to determine if the drag object
@@ -221,10 +221,10 @@ void PrefMenu::dragEnterEvent(QDragEnterEvent *event)
event->ignore();
}
-void PrefMenu::dragLeaveEvent(QDragLeaveEvent */*event*/)
+void PrefMenu::dragLeaveEvent(TQDragLeaveEvent */*event*/)
{
// see PrefMenu::dragEnterEvent why this is nescessary
- if (!frameGeometry().contains(QCursor::pos()))
+ if (!frameGeometry().contains(TQCursor::pos()))
{
KURLDrag::setTarget(0);
}
@@ -240,13 +240,13 @@ void PrefMenu::initialize()
// Set the startposition outside the panel, so there is no drag initiated
// when we use drag and click to select items. A drag is only initiated when
// you click to open the menu, and then press and drag an item.
- m_dragStartPos = QPoint(-1,-1);
+ m_dragStartPos = TQPoint(-1,-1);
if (m_root.isEmpty())
{
insertItem(KickerLib::menuIconSet("kcontrol"),
i18n("Control Center"),
- this, SLOT(launchControlCenter()));
+ this, TQT_SLOT(launchControlCenter()));
insertSeparator();
}
@@ -269,7 +269,7 @@ void PrefMenu::initialize()
int id = idStart;
- QStringList suppressGenericNames = root->suppressGenericNames();
+ TQStringList suppressGenericNames = root->suppressGenericNames();
KServiceGroup::List::ConstIterator it = list.begin();
for (; it != list.end(); ++it)
@@ -280,7 +280,7 @@ void PrefMenu::initialize()
{
KServiceGroup::Ptr g(static_cast<KServiceGroup *>(e));
- QString groupCaption = g->caption();
+ TQString groupCaption = g->caption();
// Avoid adding empty groups.
KServiceGroup::Ptr subMenuRoot = KServiceGroup::group(g->relPath());
@@ -332,8 +332,8 @@ void PrefMenu::slotExec(int id)
KSycocaEntry *e = m_entryMap[id];
KService::Ptr service = static_cast<KService *>(e);
KApplication::startServiceByDesktopPath(service->desktopEntryPath(),
- QStringList(), 0, 0, 0, "", true);
- m_dragStartPos = QPoint(-1,-1);
+ TQStringList(), 0, 0, 0, "", true);
+ m_dragStartPos = TQPoint(-1,-1);
}
void PrefMenu::clearOnClose()
@@ -358,7 +358,7 @@ void PrefMenu::slotClear()
// QPopupMenu's aboutToHide() is emitted before the popup is really hidden,
// and also before a click in the menu is handled, so do the clearing
// only after that has been handled
- QTimer::singleShot( 100, this, SLOT( slotClear()));
+ TQTimer::singleShot( 100, this, TQT_SLOT( slotClear()));
return;
}
@@ -378,7 +378,7 @@ void PrefMenu::aboutToClose()
void PrefMenu::launchControlCenter()
{
- KApplication::startServiceByDesktopName("kcontrol", QStringList(),
+ KApplication::startServiceByDesktopName("kcontrol", TQStringList(),
0, 0, 0, "", true);
}
diff --git a/kicker/menuext/prefmenu/prefmenu.h b/kicker/menuext/prefmenu/prefmenu.h
index 99c3772fc..d673fceef 100644
--- a/kicker/menuext/prefmenu/prefmenu.h
+++ b/kicker/menuext/prefmenu/prefmenu.h
@@ -24,40 +24,40 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#ifndef _prefmenu_h_
#define _prefmenu_h_
-#include <qmap.h>
+#include <tqmap.h>
#include <kpanelmenu.h>
#include <ksycocaentry.h>
-typedef QMap<int, KSycocaEntry::Ptr> EntryMap;
-typedef QPtrList<QPopupMenu> PopupMenuList;
+typedef TQMap<int, KSycocaEntry::Ptr> EntryMap;
+typedef TQPtrList<TQPopupMenu> PopupMenuList;
class PrefMenu : public KPanelMenu
{
Q_OBJECT
public:
- PrefMenu(QWidget *parent,
+ PrefMenu(TQWidget *parent,
const char *name,
- const QStringList & /*args*/);
- PrefMenu(const QString& label,
- const QString& root,
- QWidget *parent);
+ const TQStringList & /*args*/);
+ PrefMenu(const TQString& label,
+ const TQString& root,
+ TQWidget *parent);
~PrefMenu();
protected:
void insertMenuItem(KService::Ptr & s,
int nId,
int nIndex= -1,
- const QStringList *suppressGenericNames = 0);
- virtual void mousePressEvent(QMouseEvent *);
- virtual void mouseMoveEvent(QMouseEvent *);
- virtual void dragEnterEvent(QDragEnterEvent *);
- virtual void dragLeaveEvent(QDragLeaveEvent *);
+ const TQStringList *suppressGenericNames = 0);
+ virtual void mousePressEvent(TQMouseEvent *);
+ virtual void mouseMoveEvent(TQMouseEvent *);
+ virtual void dragEnterEvent(TQDragEnterEvent *);
+ virtual void dragLeaveEvent(TQDragLeaveEvent *);
bool m_clearOnClose;
- QString m_root;
- QPoint m_dragStartPos;
+ TQString m_root;
+ TQPoint m_dragStartPos;
EntryMap m_entryMap;
PopupMenuList m_subMenus;
diff --git a/kicker/menuext/recentdocs/recentdocsmenu.cpp b/kicker/menuext/recentdocs/recentdocsmenu.cpp
index 06c84d7a6..b8c3c6d81 100644
--- a/kicker/menuext/recentdocs/recentdocsmenu.cpp
+++ b/kicker/menuext/recentdocs/recentdocsmenu.cpp
@@ -21,9 +21,9 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
******************************************************************/
-#include <qdragobject.h>
-#include <qstring.h>
-#include <qstringlist.h>
+#include <tqdragobject.h>
+#include <tqstring.h>
+#include <tqstringlist.h>
#include <kglobal.h>
#include <kiconloader.h>
@@ -39,8 +39,8 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
K_EXPORT_KICKER_MENUEXT(recentdocs, RecentDocsMenu)
-RecentDocsMenu::RecentDocsMenu(QWidget *parent, const char *name,
- const QStringList &/*args*/)
+RecentDocsMenu::RecentDocsMenu(TQWidget *parent, const char *name,
+ const TQStringList &/*args*/)
: KPanelMenu(KRecentDocument::recentDocumentDirectory(), parent, name)
{
}
@@ -52,7 +52,7 @@ RecentDocsMenu::~RecentDocsMenu()
void RecentDocsMenu::initialize() {
if (initialized()) clear();
- insertItem(SmallIconSet("history_clear"), i18n("Clear History"), this, SLOT(slotClearHistory()));
+ insertItem(SmallIconSet("history_clear"), i18n("Clear History"), this, TQT_SLOT(slotClearHistory()));
insertSeparator();
_fileList = KRecentDocument::recentDocuments();
@@ -65,24 +65,24 @@ void RecentDocsMenu::initialize() {
int id = 0;
char alreadyPresentInMenu;
- QStringList previousEntries;
- for (QStringList::ConstIterator it = _fileList.begin(); it != _fileList.end(); ++it) {
+ TQStringList previousEntries;
+ for (TQStringList::ConstIterator it = _fileList.begin(); it != _fileList.end(); ++it) {
KDesktopFile f(*it, true /* read only */);
// Make sure this entry is not already present in the menu
alreadyPresentInMenu = 0;
- for ( QStringList::Iterator previt = previousEntries.begin(); previt != previousEntries.end(); ++previt ) {
- if (QString::localeAwareCompare(*previt, f.readName().replace('&', QString::fromAscii("&&") )) == 0) {
+ for ( TQStringList::Iterator previt = previousEntries.begin(); previt != previousEntries.end(); ++previt ) {
+ if (TQString::localeAwareCompare(*previt, f.readName().replace('&', TQString::fromAscii("&&") )) == 0) {
alreadyPresentInMenu = 1;
}
}
if (alreadyPresentInMenu == 0) {
// Add item to menu
- insertItem(SmallIconSet(f.readIcon()), f.readName().replace('&', QString::fromAscii("&&") ), id++);
+ insertItem(SmallIconSet(f.readIcon()), f.readName().replace('&', TQString::fromAscii("&&") ), id++);
// Append to duplicate checking list
- previousEntries.append(f.readName().replace('&', QString::fromAscii("&&") ));
+ previousEntries.append(f.readName().replace('&', TQString::fromAscii("&&") ));
}
}
@@ -103,12 +103,12 @@ void RecentDocsMenu::slotExec(int id) {
}
}
-void RecentDocsMenu::mousePressEvent(QMouseEvent* e) {
+void RecentDocsMenu::mousePressEvent(TQMouseEvent* e) {
_mouseDown = e->pos();
- QPopupMenu::mousePressEvent(e);
+ TQPopupMenu::mousePressEvent(e);
}
-void RecentDocsMenu::mouseMoveEvent(QMouseEvent* e) {
+void RecentDocsMenu::mouseMoveEvent(TQMouseEvent* e) {
KPanelMenu::mouseMoveEvent(e);
if (!(e->state() & LeftButton))
diff --git a/kicker/menuext/recentdocs/recentdocsmenu.h b/kicker/menuext/recentdocs/recentdocsmenu.h
index 1e3157495..d2e777570 100644
--- a/kicker/menuext/recentdocs/recentdocsmenu.h
+++ b/kicker/menuext/recentdocs/recentdocsmenu.h
@@ -34,7 +34,7 @@ class RecentDocsMenu : public KPanelMenu
Q_OBJECT
public:
- RecentDocsMenu(QWidget* parent, const char* name, const QStringList &/*args*/);
+ RecentDocsMenu(TQWidget* parent, const char* name, const TQStringList &/*args*/);
~RecentDocsMenu();
void initialize();
@@ -44,12 +44,12 @@ protected slots:
void slotAboutToShow();
protected:
- void mousePressEvent(QMouseEvent* e);
- void mouseMoveEvent(QMouseEvent* e);
+ void mousePressEvent(TQMouseEvent* e);
+ void mouseMoveEvent(TQMouseEvent* e);
private:
- QStringList _fileList;
- QPoint _mouseDown;
+ TQStringList _fileList;
+ TQPoint _mouseDown;
};
#endif // RECENTDOCSMENU_H
diff --git a/kicker/menuext/remote/remotemenu.cpp b/kicker/menuext/remote/remotemenu.cpp
index 42b3d5339..c09f9a825 100644
--- a/kicker/menuext/remote/remotemenu.cpp
+++ b/kicker/menuext/remote/remotemenu.cpp
@@ -27,9 +27,9 @@
#include <kdesktopfile.h>
#include <kservice.h>
-#include <qpixmap.h>
-#include <qdir.h>
-#include <qtimer.h>
+#include <tqpixmap.h>
+#include <tqdir.h>
+#include <tqtimer.h>
#include "kickerSettings.h"
@@ -38,16 +38,16 @@
K_EXPORT_KICKER_MENUEXT(remotemenu, RemoteMenu)
-RemoteMenu::RemoteMenu(QWidget *parent, const char *name,
- const QStringList &/*args*/)
+RemoteMenu::RemoteMenu(TQWidget *parent, const char *name,
+ const TQStringList &/*args*/)
: KPanelMenu(parent, name), KDirNotify()
{
KGlobal::dirs()->addResourceType("remote_entries",
KStandardDirs::kde_default("data") + "remoteview");
- QString path = KGlobal::dirs()->saveLocation("remote_entries");
+ TQString path = KGlobal::dirs()->saveLocation("remote_entries");
- QDir dir = path;
+ TQDir dir = path;
if (!dir.exists())
{
dir.cdUp();
@@ -68,35 +68,35 @@ void RemoteMenu::initialize()
}
id = insertItem(SmallIcon("wizard"), i18n("Add Network Folder"));
- connectItem(id, this, SLOT(startWizard()));
+ connectItem(id, this, TQT_SLOT(startWizard()));
id = insertItem(SmallIcon("kfm"), i18n("Manage Network Folders"));
- connectItem(id, this, SLOT(openRemoteDir()));
+ connectItem(id, this, TQT_SLOT(openRemoteDir()));
insertSeparator();
m_desktopMap.clear();
- QStringList names_found;
- QStringList dirList = KGlobal::dirs()->resourceDirs("remote_entries");
+ TQStringList names_found;
+ TQStringList dirList = KGlobal::dirs()->resourceDirs("remote_entries");
- QStringList::ConstIterator dirpath = dirList.begin();
- QStringList::ConstIterator end = dirList.end();
+ TQStringList::ConstIterator dirpath = dirList.begin();
+ TQStringList::ConstIterator end = dirList.end();
for(; dirpath!=end; ++dirpath)
{
- QDir dir = *dirpath;
+ TQDir dir = *dirpath;
if (!dir.exists()) continue;
- QStringList filenames
- = dir.entryList( QDir::Files | QDir::Readable );
+ TQStringList filenames
+ = dir.entryList( TQDir::Files | TQDir::Readable );
- QStringList::ConstIterator name = filenames.begin();
- QStringList::ConstIterator endf = filenames.end();
+ TQStringList::ConstIterator name = filenames.begin();
+ TQStringList::ConstIterator endf = filenames.end();
for(; name!=endf; ++name)
{
if (!names_found.contains(*name))
{
names_found.append(*name);
- QString filename = *dirpath+*name;
+ TQString filename = *dirpath+*name;
KDesktopFile desktop(filename);
id = insertItem(SmallIcon(desktop.readIcon()), desktop.readName());
m_desktopMap[id] = filename;
diff --git a/kicker/menuext/remote/remotemenu.h b/kicker/menuext/remote/remotemenu.h
index 1e46bb4e3..607e1fc64 100644
--- a/kicker/menuext/remote/remotemenu.h
+++ b/kicker/menuext/remote/remotemenu.h
@@ -22,7 +22,7 @@
#include <kdirnotify.h>
#include <kpanelmenu.h>
-#include <qmap.h>
+#include <tqmap.h>
class RemoteMenu : public KPanelMenu, public KDirNotify
{
@@ -30,8 +30,8 @@ class RemoteMenu : public KPanelMenu, public KDirNotify
K_DCOP
public:
- RemoteMenu(QWidget *parent, const char *name,
- const QStringList & /*args*/);
+ RemoteMenu(TQWidget *parent, const char *name,
+ const TQStringList & /*args*/);
~RemoteMenu();
k_dcop:
@@ -47,7 +47,7 @@ class RemoteMenu : public KPanelMenu, public KDirNotify
void slotExec(int id);
private:
- QMap<int, QString> m_desktopMap;
+ TQMap<int, TQString> m_desktopMap;
};
#endif
diff --git a/kicker/menuext/system/systemmenu.cpp b/kicker/menuext/system/systemmenu.cpp
index 68c3f5c66..12ec087d8 100644
--- a/kicker/menuext/system/systemmenu.cpp
+++ b/kicker/menuext/system/systemmenu.cpp
@@ -21,19 +21,19 @@
#include <krun.h>
#include <kiconloader.h>
-#include <qpixmap.h>
+#include <tqpixmap.h>
#include "global.h"
K_EXPORT_KICKER_MENUEXT(systemmenu, SystemMenu)
-SystemMenu::SystemMenu(QWidget *parent, const char *name,
- const QStringList &/*args*/)
+SystemMenu::SystemMenu(TQWidget *parent, const char *name,
+ const TQStringList &/*args*/)
: KPanelMenu( parent, name)
{
- connect( &m_dirLister, SIGNAL( completed() ),
- this, SLOT( slotCompleted() ) );
+ connect( &m_dirLister, TQT_SIGNAL( completed() ),
+ this, TQT_SLOT( slotCompleted() ) );
m_dirLister.openURL(KURL("system:/"));
}
@@ -42,8 +42,8 @@ SystemMenu::~SystemMenu()
{
}
-void SystemMenu::append(const QString &icon, const KURL &url,
- const QString &label)
+void SystemMenu::append(const TQString &icon, const KURL &url,
+ const TQString &label)
{
int id = insertItem(KickerLib::menuIconSet(icon), label);
m_urlMap.insert(id, url);
@@ -68,9 +68,9 @@ void SystemMenu::initialize()
for (; it!=end; ++it)
{
- QString icon = (*it)->iconName();
+ TQString icon = (*it)->iconName();
KURL url = (*it)->url();
- QString name = (*it)->name();
+ TQString name = (*it)->name();
append(icon, url, name);
}
}
diff --git a/kicker/menuext/system/systemmenu.h b/kicker/menuext/system/systemmenu.h
index 6f118d21c..f25280989 100644
--- a/kicker/menuext/system/systemmenu.h
+++ b/kicker/menuext/system/systemmenu.h
@@ -30,8 +30,8 @@ class SystemMenu : public KPanelMenu
Q_OBJECT
public:
- SystemMenu(QWidget *parent, const char *name,
- const QStringList & /*args*/);
+ SystemMenu(TQWidget *parent, const char *name,
+ const TQStringList & /*args*/);
~SystemMenu();
protected slots:
@@ -41,10 +41,10 @@ class SystemMenu : public KPanelMenu
void slotCompleted();
private:
- void append(const QString &icon, const KURL &url, const QString &label);
+ void append(const TQString &icon, const KURL &url, const TQString &label);
KDirLister m_dirLister;
KFileItemList m_entries;
- QMap<int, KURL> m_urlMap;
+ TQMap<int, KURL> m_urlMap;
};
#endif
diff --git a/kicker/menuext/tom/tom.cc b/kicker/menuext/tom/tom.cc
index 80ea3e71d..3a4ebf4ed 100644
--- a/kicker/menuext/tom/tom.cc
+++ b/kicker/menuext/tom/tom.cc
@@ -23,15 +23,15 @@ using namespace std;
#include <pwd.h>
#include <sys/types.h>
-#include <qdir.h>
-#include <qimage.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qpainter.h>
-#include <qregexp.h>
-#include <qsettings.h>
-#include <qstyle.h>
-#include <qfile.h>
+#include <tqdir.h>
+#include <tqimage.h>
+#include <tqlabel.h>
+#include <tqlayout.h>
+#include <tqpainter.h>
+#include <tqregexp.h>
+#include <tqsettings.h>
+#include <tqstyle.h>
+#include <tqfile.h>
#include <dcopclient.h>
#include <kapplication.h>
@@ -69,51 +69,51 @@ extern "C"
}
};
-TOMFactory::TOMFactory(QObject *parent, const char *name)
+TOMFactory::TOMFactory(TQObject *parent, const char *name)
: KLibFactory(parent, name)
{
}
-QObject* TOMFactory::createObject(QObject *parent, const char *name, const char*, const QStringList&)
+TQObject* TOMFactory::createObject(TQObject *parent, const char *name, const char*, const TQStringList&)
{
- return new TOM((QWidget*)parent, name);
+ return new TOM((TQWidget*)parent, name);
}
-#include <qmenudata.h>
+#include <tqmenudata.h>
/*
* TODO: switch the backgroundmode when translucency turns on/off
* TODO: catch font changes too?
*/
-class runMenuWidget : public QWidget, public QMenuItem
+class runMenuWidget : public TQWidget, public QMenuItem
{
public:
runMenuWidget(KPopupMenu* parent, int index)
- : QWidget (parent),
+ : TQWidget (parent),
m_menu(parent),
m_index(index)
{
setFocusPolicy(StrongFocus);
- QHBoxLayout* runLayout = new QHBoxLayout(this);
+ TQHBoxLayout* runLayout = new TQHBoxLayout(this);
textRect = fontMetrics().boundingRect(i18n("Run:"));
runLayout->setSpacing(KDialog::spacingHint());
runLayout->addSpacing((KDialog::spacingHint() * 3) + KIcon::SizeMedium + textRect.width());
icon = DesktopIcon("run", KIcon::SizeMedium);
- /*QLabel* l1 = new QLabel(this);
- QPixmap foo = DesktopIcon("run", KIcon::SizeMedium);
+ /*TQLabel* l1 = new TQLabel(this);
+ TQPixmap foo = DesktopIcon("run", KIcon::SizeMedium);
cout << "foo is: " << foo.width() << " by " << foo.height() << endl;
l1->setPixmap(foo);
runLayout->addWidget(l1);*/
- /*QLabel* l2 = new QLabel(i18n("&Run: "), this);
+ /*TQLabel* l2 = new TQLabel(i18n("&Run: "), this);
l2->setBackgroundMode(Qt::X11ParentRelative, Qt::X11ParentRelative);
l2->setBuddy(this);
runLayout->addWidget(l2);*/
m_runEdit = new KHistoryCombo(this);
- m_runEdit->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
+ m_runEdit->setSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Preferred);
runLayout->addWidget(m_runEdit, 10);
runLayout->addSpacing(KDialog::spacingHint());
- QSettings settings;
+ TQSettings settings;
if (settings.readEntry("/KStyle/Settings/MenuTransparencyEngine", "Disabled") != "Disabled")
{
setBackgroundMode(Qt::X11ParentRelative, Qt::X11ParentRelative);
@@ -138,18 +138,18 @@ class runMenuWidget : public QWidget, public QMenuItem
~runMenuWidget() {}
- void paintEvent(QPaintEvent * /*e*/)
+ void paintEvent(TQPaintEvent * /*e*/)
{
- QPainter p(this);
- QRect r(rect());
+ TQPainter p(this);
+ TQRect r(rect());
// ew, nasty hack. may result in coredumps due to horrid C-style cast???
- kapp->style().drawControl(QStyle::CE_PopupMenuItem, &p, m_menu, r, palette().active(), QStyle::Style_Enabled,
- QStyleOption(static_cast<QMenuItem*>(this), 0, KIcon::SizeMedium ));
+ kapp->style().drawControl(TQStyle::CE_PopupMenuItem, &p, m_menu, r, palette().active(), TQStyle::Style_Enabled,
+ TQStyleOption(static_cast<TQMenuItem*>(this), 0, KIcon::SizeMedium ));
p.drawPixmap(KDialog::spacingHint(), 1, icon);
p.drawText((KDialog::spacingHint() * 2) + KIcon::SizeMedium, textRect.height() + ((height() - textRect.height()) / 2), i18n("Run:"));
}
- void focusInEvent (QFocusEvent* e)
+ void focusInEvent (TQFocusEvent* e)
{
if (!e || e->gotFocus())
{
@@ -158,7 +158,7 @@ class runMenuWidget : public QWidget, public QMenuItem
}
}
- void enterEvent(QEvent*)
+ void enterEvent(TQEvent*)
{
focusInEvent(0);
}
@@ -166,12 +166,12 @@ class runMenuWidget : public QWidget, public QMenuItem
private:
KPopupMenu* m_menu;
KHistoryCombo* m_runEdit;
- QPixmap icon;
- QRect textRect;
+ TQPixmap icon;
+ TQRect textRect;
int m_index;
};
-TOM::TOM(QWidget *parent, const char *name)
+TOM::TOM(TQWidget *parent, const char *name)
: KPanelMenu(parent, name),
m_maxIndex(0)
{
@@ -199,7 +199,7 @@ TOM::~TOM()
slotClear();
}
-void TOM::initializeRecentApps(QPopupMenu* menu)
+void TOM::initializeRecentApps(TQPopupMenu* menu)
{
/*
* TODO: make this real
@@ -217,7 +217,7 @@ void TOM::initializeRecentDocs()
{
m_recentDocsMenu->clear();
m_recentDocsMenu->insertItem(SmallIconSet("history_clear"), i18n("Clear History"),
- this, SLOT(clearRecentDocHistory()));
+ this, TQT_SLOT(clearRecentDocHistory()));
m_recentDocsMenu->insertSeparator();
m_recentDocURLs = KRecentDocument::recentDocuments();
@@ -229,7 +229,7 @@ void TOM::initializeRecentDocs()
}
int id = 0;
- for (QStringList::ConstIterator it = m_recentDocURLs.begin();
+ for (TQStringList::ConstIterator it = m_recentDocURLs.begin();
it != m_recentDocURLs.end();
++it)
{
@@ -258,8 +258,8 @@ int TOM::appendTaskGroup(KConfig& config, bool inSubMenu)
return 0;
}
- QString name = config.readEntry("Name", i18n("Unknown"));
- QString icon = config.readEntry("Icon");
+ TQString name = config.readEntry("Name", i18n("Unknown"));
+ TQString icon = config.readEntry("Icon");
int numTasks = config.readNumEntry("NumTasks", 0);
if (numTasks < 1)
@@ -272,7 +272,7 @@ int TOM::appendTaskGroup(KConfig& config, bool inSubMenu)
{
taskGroup = new KPopupMenu(this);
- if (icon != QString::null)
+ if (icon != TQString::null)
{
insertItem(DesktopIcon(icon, KIcon::SizeMedium), name, taskGroup);
}
@@ -289,7 +289,7 @@ int TOM::appendTaskGroup(KConfig& config, bool inSubMenu)
int foundTasks = 0;
for (int i = 0; i < numTasks; ++i)
{
- QString groupName = QString("Task%1").arg(i);
+ TQString groupName = TQString("Task%1").arg(i);
if (config.hasGroup(groupName))
{
@@ -300,10 +300,10 @@ int TOM::appendTaskGroup(KConfig& config, bool inSubMenu)
continue;
}
- QString name = config.readEntry("Name");
+ TQString name = config.readEntry("Name");
// in case the name contains an ampersand, double 'em up
name.replace("&", "&&");
- QString desktopfile = config.readPathEntry("DesktopFile");
+ TQString desktopfile = config.readPathEntry("DesktopFile");
KService::Ptr pService = KService::serviceByDesktopPath(desktopfile);
if (!pService)
@@ -316,12 +316,12 @@ int TOM::appendTaskGroup(KConfig& config, bool inSubMenu)
}
}
- QString execName = pService->name();
- QString icon = pService->icon();
+ TQString execName = pService->name();
+ TQString icon = pService->icon();
if (m_detailedTaskEntries && !execName.isEmpty())
{
- QString tmp = i18n("%1 (%2)");
+ TQString tmp = i18n("%1 (%2)");
if (m_detailedNamesFirst)
{
@@ -341,7 +341,7 @@ int TOM::appendTaskGroup(KConfig& config, bool inSubMenu)
else
{
- QIconSet iconset = BarIconSet(icon, 22);
+ TQIconSet iconset = BarIconSet(icon, 22);
if (iconset.isNull())
taskGroup->insertItem(name, m_maxIndex);
else
@@ -365,13 +365,13 @@ int TOM::appendTaskGroup(KConfig& config, bool inSubMenu)
return 0;
}
- connect(taskGroup, SIGNAL(activated(int)), this, SLOT(runTask(int)));
+ connect(taskGroup, TQT_SIGNAL(activated(int)), this, TQT_SLOT(runTask(int)));
// so we have an actual task group menu with tasks, let's add it
if (inSubMenu)
{
- QObject::connect(taskGroup, SIGNAL(aboutToShowContextMenu(KPopupMenu*, int, QPopupMenu*)),
- this, SLOT(contextualizeRMBmenu(KPopupMenu*, int, QPopupMenu*)));
+ TQObject::connect(taskGroup, TQT_SIGNAL(aboutToShowContextMenu(KPopupMenu*, int, TQPopupMenu*)),
+ this, TQT_SLOT(contextualizeRMBmenu(KPopupMenu*, int, TQPopupMenu*)));
m_submenus.append(taskGroup);
@@ -382,14 +382,14 @@ int TOM::appendTaskGroup(KConfig& config, bool inSubMenu)
{
taskGroup->insertSeparator();
taskGroup->insertItem("Modify These Tasks", configureMenuID);
- QPopupMenu* rmbMenu = taskGroup->contextMenu();
+ TQPopupMenu* rmbMenu = taskGroup->contextMenu();
rmbMenu->setFont(m_largerFont);
KPopupTitle* title = new KPopupTitle();
title->setText(i18n("%1 Menu Editor").arg(name));
rmbMenu->insertItem(title, contextMenuTitleID);
rmbMenu->insertItem(i18n("Add This Task to Panel"));
rmbMenu->insertItem(i18n("Modify This Task..."));
- rmbMenu->insertItem(i18n("Remove This Task..."), this, SLOT(removeTask()));
+ rmbMenu->insertItem(i18n("Remove This Task..."), this, TQT_SLOT(removeTask()));
rmbMenu->insertItem(i18n("Insert New Task..."));
}
}
@@ -428,27 +428,27 @@ void TOM::initialize()
/*if (!loadSidePixmap())
{
- m_sidePixmap = m_sideTilePixmap = QPixmap();
+ m_sidePixmap = m_sideTilePixmap = TQPixmap();
}
else
{
- connect(kapp, SIGNAL(kdisplayPaletteChanged()), SLOT(paletteChanged()));
+ connect(kapp, TQT_SIGNAL(kdisplayPaletteChanged()), TQT_SLOT(paletteChanged()));
}*/
// TASKS
insertTitle(i18n("Tasks"), contextMenuTitleID);
- QStringList dirs = KGlobal::dirs()->findDirs("data", "kicker/tom/");
- QStringList::ConstIterator dIt = dirs.begin();
- QStringList::ConstIterator dEnd = dirs.end();
+ TQStringList dirs = KGlobal::dirs()->findDirs("data", "kicker/tom/");
+ TQStringList::ConstIterator dIt = dirs.begin();
+ TQStringList::ConstIterator dEnd = dirs.end();
for (; dIt != dEnd; ++dIt )
{
- QDir dir(*dIt);
+ TQDir dir(*dIt);
- QStringList entries = dir.entryList("*rc", QDir::Files);
- QStringList::ConstIterator eIt = entries.begin();
- QStringList::ConstIterator eEnd = entries.end();
+ TQStringList entries = dir.entryList("*rc", TQDir::Files);
+ TQStringList::ConstIterator eIt = entries.begin();
+ TQStringList::ConstIterator eEnd = entries.end();
for (; eIt != eEnd; ++eIt )
{
@@ -457,7 +457,7 @@ void TOM::initialize()
}
}
- PanelServiceMenu* moreApps = new PanelServiceMenu(QString::null, QString::null, this, "More Applications");
+ PanelServiceMenu* moreApps = new PanelServiceMenu(TQString::null, TQString::null, this, "More Applications");
moreApps->setFont(m_largerFont);
insertItem(DesktopIcon("misc", KIcon::SizeMedium), i18n("More Applications"), moreApps);
m_submenus.append(moreApps);
@@ -472,9 +472,9 @@ void TOM::initialize()
// DESTINATIONS
insertTitle(i18n("Destinations"), destMenuTitleID);
int numDests = 0;
- QString destinationsConfig = locate("appdata", "tom/destinations");
+ TQString destinationsConfig = locate("appdata", "tom/destinations");
- if (!destinationsConfig.isEmpty() && QFile::exists(destinationsConfig))
+ if (!destinationsConfig.isEmpty() && TQFile::exists(destinationsConfig))
{
KConfig config(destinationsConfig);
numDests = appendTaskGroup(config, false);
@@ -486,7 +486,7 @@ void TOM::initialize()
}
else if (kapp->authorize("run_command"))
{
- insertItem(DesktopIcon("run", KIcon::SizeMedium), i18n("Run Command..."), this, SLOT(runCommand()));
+ insertItem(DesktopIcon("run", KIcon::SizeMedium), i18n("Run Command..."), this, TQT_SLOT(runCommand()));
}
// RECENTLY USED ITEMS
@@ -494,8 +494,8 @@ void TOM::initialize()
m_recentDocsMenu = new KPopupMenu(this, "recentDocs");
m_recentDocsMenu->setFont(m_largerFont);
- connect(m_recentDocsMenu, SIGNAL(aboutToShow()), this, SLOT(initializeRecentDocs()));
- connect(m_recentDocsMenu, SIGNAL(activated(int)), this, SLOT(openRecentDocument(int)));
+ connect(m_recentDocsMenu, TQT_SIGNAL(aboutToShow()), this, TQT_SLOT(initializeRecentDocs()));
+ connect(m_recentDocsMenu, TQT_SIGNAL(activated(int)), this, TQT_SLOT(openRecentDocument(int)));
insertItem(DesktopIcon("document", KIcon::SizeMedium), i18n("Recent Documents"), m_recentDocsMenu);
m_submenus.append(m_recentDocsMenu);
@@ -512,16 +512,16 @@ void TOM::initialize()
// if we have no destinations, put the run command here
if (numDests == 0 && kapp->authorize("run_command"))
{
- insertItem(DesktopIcon("run", KIcon::SizeMedium), i18n("Run Command..."), this, SLOT(runCommand()));
+ insertItem(DesktopIcon("run", KIcon::SizeMedium), i18n("Run Command..."), this, TQT_SLOT(runCommand()));
}
KConfig* config = KGlobal::config();
- QStringList menu_ext = config->readListEntry("Extensions");
+ TQStringList menu_ext = config->readListEntry("Extensions");
if (!menu_ext.isEmpty())
{
bool needSeparator = false;
- for (QStringList::ConstIterator it = menu_ext.begin(); it != menu_ext.end(); ++it)
+ for (TQStringList::ConstIterator it = menu_ext.begin(); it != menu_ext.end(); ++it)
{
MenuInfo info(*it);
if (!info.isValid())
@@ -546,11 +546,11 @@ void TOM::initialize()
}
- QString username;
+ TQString username;
struct passwd *userInfo = getpwuid(getuid());
if (userInfo)
{
- username = QString::fromLocal8Bit(userInfo->pw_gecos);
+ username = TQString::fromLocal8Bit(userInfo->pw_gecos);
if (username.find(',') != -1)
{
// Remove everything from and including first comma
@@ -559,12 +559,12 @@ void TOM::initialize()
if (username.isEmpty())
{
- username = QString::fromLocal8Bit(userInfo->pw_name);
+ username = TQString::fromLocal8Bit(userInfo->pw_name);
}
}
insertItem(DesktopIcon("exit", KIcon::SizeMedium),
- i18n("Logout %1").arg(username), this, SLOT(logout()));
+ i18n("Logout %1").arg(username), this, TQT_SLOT(logout()));
}
void TOM::reload()
@@ -573,7 +573,7 @@ void TOM::reload()
initialize();
}
-void TOM::contextualizeRMBmenu(KPopupMenu* menu, int menuItem, QPopupMenu* ctxMenu)
+void TOM::contextualizeRMBmenu(KPopupMenu* menu, int menuItem, TQPopupMenu* ctxMenu)
{
if (menuItem == configureMenuID)
{
@@ -582,7 +582,7 @@ void TOM::contextualizeRMBmenu(KPopupMenu* menu, int menuItem, QPopupMenu* ctxMe
}
ctxMenu->removeItem(contextMenuTitleID);
- QString text = menu->text(menuItem);
+ TQString text = menu->text(menuItem);
int parens = text.find('(') - 1;
if (parens > 0)
{
@@ -608,7 +608,7 @@ void TOM::slotExec(int /* id */)
void TOM::removeTask()
{
// TODO: write this change out to the appropriate config file
- QString task = KPopupMenu::contextMenuFocus()->text(KPopupMenu::contextMenuFocusItem());
+ TQString task = KPopupMenu::contextMenuFocus()->text(KPopupMenu::contextMenuFocusItem());
if (KMessageBox::warningContinueCancel(this,
i18n("<qt>Are you sure you want to remove the <strong>%1</strong> task?<p>"
"<em>Tip: You can restore the task after it has been removed by selecting the &quot;Modify These Tasks&quot; entry</em></qt>").arg(task),
@@ -629,12 +629,12 @@ void TOM::removeTask()
bool TOM::loadSidePixmap()
{
KConfig *config = KGlobal::config();
- QColor color = palette().active().highlight();
- QImage image;
+ TQColor color = palette().active().highlight();
+ TQImage image;
config->setGroup("WM");
- QColor activeTitle = config->readColorEntry("activeBackground", &color);
- QColor inactiveTitle = config->readColorEntry("inactiveBackground", &color);
+ TQColor activeTitle = config->readColorEntry("activeBackground", &color);
+ TQColor inactiveTitle = config->readColorEntry("inactiveBackground", &color);
config->setGroup("KMenu");
if (!config->readBoolEntry("Usem_sidePixmap", true))
@@ -667,8 +667,8 @@ bool TOM::loadSidePixmap()
}
color.setRgb(r, g, b);
- QString sideName = config->readEntry("SideName", "kside.png");
- QString sideTileName = config->readEntry("SideTileName", "kside_tile.png");
+ TQString sideName = config->readEntry("SideName", "kside.png");
+ TQString sideTileName = config->readEntry("SideTileName", "kside_tile.png");
image.load(locate("data", "kicker/pics/" + sideName));
@@ -699,8 +699,8 @@ bool TOM::loadSidePixmap()
if (m_sideTilePixmap.height() < 100)
{
int tiles = (int)(100 / m_sideTilePixmap.height()) + 1;
- QPixmap preTiledPixmap(m_sideTilePixmap.width(), m_sideTilePixmap.height() * tiles);
- QPainter p(&preTiledPixmap);
+ TQPixmap preTiledPixmap(m_sideTilePixmap.width(), m_sideTilePixmap.height() * tiles);
+ TQPainter p(&preTiledPixmap);
p.drawTiledPixmap(preTiledPixmap.rect(), m_sideTilePixmap);
m_sideTilePixmap = preTiledPixmap;
}
@@ -711,15 +711,15 @@ bool TOM::loadSidePixmap()
void TOM::paletteChanged()
{
if (!loadSidePixmap())
- m_sidePixmap = m_sideTilePixmap = QPixmap();
+ m_sidePixmap = m_sideTilePixmap = TQPixmap();
}
-void TOM::setMinimumSize(const QSize & s)
+void TOM::setMinimumSize(const TQSize & s)
{
KPanelMenu::setMinimumSize(s.width() + m_sidePixmap.width(), s.height());
}
-void TOM::setMaximumSize(const QSize & s)
+void TOM::setMaximumSize(const TQSize & s)
{
KPanelMenu::setMaximumSize(s.width() + m_sidePixmap.width(), s.height());
}
@@ -734,33 +734,33 @@ void TOM::setMaximumSize(int w, int h)
KPanelMenu::setMaximumSize(w + m_sidePixmap.width(), h);
}
-QRect TOM::sideImageRect()
+TQRect TOM::sideImageRect()
{
- return QStyle::visualRect( QRect( frameWidth(), frameWidth(), m_sidePixmap.width(),
+ return TQStyle::visualRect( TQRect( frameWidth(), frameWidth(), m_sidePixmap.width(),
height() - 2*frameWidth() ), this );
}
-void TOM::resizeEvent(QResizeEvent * e)
+void TOM::resizeEvent(TQResizeEvent * e)
{
- setFrameRect( QStyle::visualRect( QRect( m_sidePixmap.width(), 0,
+ setFrameRect( TQStyle::visualRect( TQRect( m_sidePixmap.width(), 0,
width() - m_sidePixmap.width(), height() ), this ) );
}
-void TOM::paintEvent(QPaintEvent * e)
+void TOM::paintEvent(TQPaintEvent * e)
{
if (m_sidePixmap.isNull()) {
KPanelMenu::paintEvent(e);
return;
}
- QPainter p(this);
+ TQPainter p(this);
- style().drawPrimitive( QStyle::PE_PanelPopup, &p,
- QRect( 0, 0, width(), height() ),
- colorGroup(), QStyle::Style_Default,
- QStyleOption( frameWidth(), 0 ) );
+ style().drawPrimitive( TQStyle::PE_PanelPopup, &p,
+ TQRect( 0, 0, width(), height() ),
+ colorGroup(), TQStyle::Style_Default,
+ TQStyleOption( frameWidth(), 0 ) );
- QRect r = sideImageRect();
+ TQRect r = sideImageRect();
r.setBottom( r.bottom() - m_sidePixmap.height() );
p.drawTiledPixmap( r, m_sideTilePixmap );
@@ -771,40 +771,40 @@ void TOM::paintEvent(QPaintEvent * e)
drawContents( &p );
}
-QMouseEvent TOM::translateMouseEvent( QMouseEvent* e )
+TQMouseEvent TOM::translateMouseEvent( TQMouseEvent* e )
{
- QRect side = sideImageRect();
+ TQRect side = sideImageRect();
if ( !side.contains( e->pos() ) )
return *e;
- QPoint newpos( e->pos() );
- QApplication::reverseLayout() ?
+ TQPoint newpos( e->pos() );
+ TQApplication::reverseLayout() ?
newpos.setX( newpos.x() - side.width() ) :
newpos.setX( newpos.x() + side.width() );
- QPoint newglobal( e->globalPos() );
- QApplication::reverseLayout() ?
+ TQPoint newglobal( e->globalPos() );
+ TQApplication::reverseLayout() ?
newglobal.setX( newpos.x() - side.width() ) :
newglobal.setX( newpos.x() + side.width() );
- return QMouseEvent( e->type(), newpos, newglobal, e->button(), e->state() );
+ return TQMouseEvent( e->type(), newpos, newglobal, e->button(), e->state() );
}
-void TOM::mousePressEvent(QMouseEvent * e)
+void TOM::mousePressEvent(TQMouseEvent * e)
{
- QMouseEvent newEvent = translateMouseEvent(e);
+ TQMouseEvent newEvent = translateMouseEvent(e);
KPanelMenu::mousePressEvent( &newEvent );
}
-void TOM::mouseReleaseEvent(QMouseEvent *e)
+void TOM::mouseReleaseEvent(TQMouseEvent *e)
{
- QMouseEvent newEvent = translateMouseEvent(e);
+ TQMouseEvent newEvent = translateMouseEvent(e);
KPanelMenu::mouseReleaseEvent( &newEvent );
}
-void TOM::mouseMoveEvent(QMouseEvent *e)
+void TOM::mouseMoveEvent(TQMouseEvent *e)
{
- QMouseEvent newEvent = translateMouseEvent(e);
+ TQMouseEvent newEvent = translateMouseEvent(e);
KPanelMenu::mouseMoveEvent( &newEvent );
}*/
@@ -812,8 +812,8 @@ extern int kicker_screen_number;
void TOM::runCommand()
{
- QByteArray data;
- QCString appname( "kdesktop" );
+ TQByteArray data;
+ TQCString appname( "kdesktop" );
if ( kicker_screen_number )
appname.sprintf("kdesktop-screen-%d", kicker_screen_number);
@@ -828,7 +828,7 @@ void TOM::runTask(int id)
kapp->propagateSessionManager();
KApplication::startServiceByDesktopPath(m_tasks[id]->desktopEntryPath(),
- QStringList(), 0, 0, 0, "", true);
+ TQStringList(), 0, 0, 0, "", true);
}
void TOM::clearRecentDocHistory()
diff --git a/kicker/menuext/tom/tom.h b/kicker/menuext/tom/tom.h
index 663cb05d6..f658a1ffe 100644
--- a/kicker/menuext/tom/tom.h
+++ b/kicker/menuext/tom/tom.h
@@ -19,7 +19,7 @@
#ifndef __tom_h_
#define __tom_h_
-#include <qpixmap.h>
+#include <tqpixmap.h>
#include <kpanelmenu.h>
#include <klibloader.h>
@@ -27,20 +27,20 @@
class KPopupMenu;
class QPopupMenu;
-typedef QPtrList<QPopupMenu> PopupMenuList;
-typedef QMap<int, KService::Ptr> TaskMap;
+typedef TQPtrList<TQPopupMenu> PopupMenuList;
+typedef TQMap<int, KService::Ptr> TaskMap;
class TOM : public KPanelMenu
{
Q_OBJECT
public:
- TOM(QWidget *parent = 0, const char *name = 0);
+ TOM(TQWidget *parent = 0, const char *name = 0);
~TOM();
// for the side image
- /*void setMinimumSize(const QSize &);
- void setMaximumSize(const QSize &);
+ /*void setMinimumSize(const TQSize &);
+ void setMaximumSize(const TQSize &);
void setMinimumSize(int, int);
void setMaximumSize(int, int); */
@@ -49,7 +49,7 @@ class TOM : public KPanelMenu
void slotExec(int);
//void configChanged();
void initialize();
- void contextualizeRMBmenu(KPopupMenu* menu, int menuItem, QPopupMenu* ctxMenu);
+ void contextualizeRMBmenu(KPopupMenu* menu, int menuItem, TQPopupMenu* ctxMenu);
//void paletteChanged();
void clearRecentDocHistory();
void runCommand();
@@ -67,43 +67,43 @@ class TOM : public KPanelMenu
void reload();
int appendTaskGroup(KConfig& config, bool inSubMenu = true );
- void initializeRecentApps(QPopupMenu* menu);
- //int insertTOMTitle(QPopupMenu* menu, const QString &text, int id = -1, int index = -1);
+ void initializeRecentApps(TQPopupMenu* menu);
+ //int insertTOMTitle(TQPopupMenu* menu, const TQString &text, int id = -1, int index = -1);
/*
* this stuff should be shared w/the kmenu
- QRect sideImageRect();
- QMouseEvent translateMouseEvent( QMouseEvent* e );
- void resizeEvent(QResizeEvent *);
- void paintEvent(QPaintEvent *);
- void mousePressEvent(QMouseEvent *);
- void mouseReleaseEvent(QMouseEvent *);
- void mouseMoveEvent(QMouseEvent *);
+ TQRect sideImageRect();
+ TQMouseEvent translateMouseEvent( TQMouseEvent* e );
+ void resizeEvent(TQResizeEvent *);
+ void paintEvent(TQPaintEvent *);
+ void mousePressEvent(TQMouseEvent *);
+ void mouseReleaseEvent(TQMouseEvent *);
+ void mouseMoveEvent(TQMouseEvent *);
bool loadSidePixmap();
- QPixmap m_sidePixmap;
- QPixmap m_sideTilePixmap;*/
+ TQPixmap m_sidePixmap;
+ TQPixmap m_sideTilePixmap;*/
PopupMenuList m_submenus;
- QFont m_largerFont;
+ TQFont m_largerFont;
int m_maxIndex;
bool m_isImmutable;
bool m_detailedTaskEntries;
bool m_detailedNamesFirst;
TaskMap m_tasks;
KPopupMenu* m_recentDocsMenu;
- QStringList m_recentDocURLs;
+ TQStringList m_recentDocURLs;
};
class TOMFactory : public KLibFactory
{
public:
- TOMFactory(QObject *parent = 0, const char *name = 0);
+ TOMFactory(TQObject *parent = 0, const char *name = 0);
protected:
- QObject* createObject(QObject *parent = 0, const char *name = 0,
- const char *classname = "QObject",
- const QStringList& args = QStringList());
+ TQObject* createObject(TQObject *parent = 0, const char *name = 0,
+ const char *classname = "TQObject",
+ const TQStringList& args = TQStringList());
};
diff --git a/kicker/menuext/konsole/konsole_mnu.cpp b/kicker/menuext/konsole/konsole_mnu.cpp
index 87df6f268..afd1127f6 100644
--- a/kicker/menuext/konsole/konsole_mnu.cpp
+++ b/kicker/menuext/konsole/konsole_mnu.cpp
@@ -27,8 +27,8 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <unistd.h>
#include <sys/stat.h>
-#include <qdir.h>
-#include <qfileinfo.h>
+#include <tqdir.h>
+#include <tqfileinfo.h>
#include <kapplication.h>
#include <kglobal.h>
@@ -44,7 +44,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
K_EXPORT_KICKER_MENUEXT(konsole, KonsoleMenu)
-KonsoleMenu::KonsoleMenu(QWidget *parent, const char *name, const QStringList& /* args */)
+KonsoleMenu::KonsoleMenu(TQWidget *parent, const char *name, const TQStringList& /* args */)
: KPanelMenu("", parent, name),
m_profileMenu(0),
m_bookmarksSession(0),
@@ -58,8 +58,8 @@ KonsoleMenu::~KonsoleMenu()
}
static void insertItemSorted(KPopupMenu *menu,
- const QIconSet &iconSet,
- const QString &txt, int id)
+ const TQIconSet &iconSet,
+ const TQString &txt, int id)
{
const int defaultId = 1; // The id of the 'new' item.
int index = menu->indexOf(defaultId);
@@ -96,17 +96,17 @@ void KonsoleMenu::initialize()
setInitialized(true);
- QStringList list = KGlobal::dirs()->findAllResources("data",
+ TQStringList list = KGlobal::dirs()->findAllResources("data",
"konsole/*.desktop",
false, true);
- QString defaultShell = locate("data", "konsole/shell.desktop");
+ TQString defaultShell = locate("data", "konsole/shell.desktop");
list.prepend(defaultShell);
int id = 1;
sessionList.clear();
- for (QStringList::ConstIterator it = list.begin(); it != list.end(); ++it)
+ for (TQStringList::ConstIterator it = list.begin(); it != list.end(); ++it)
{
if ((*it == defaultShell) && (id != 1))
{
@@ -115,10 +115,10 @@ void KonsoleMenu::initialize()
KSimpleConfig conf(*it, true /* read only */);
conf.setDesktopGroup();
- QString text = conf.readEntry("Name");
+ TQString text = conf.readEntry("Name");
// try to locate the binary
- QString exec= conf.readPathEntry("Exec");
+ TQString exec= conf.readPathEntry("Exec");
if (exec.startsWith("su -c \'"))
{
exec = exec.mid(7,exec.length()-8);
@@ -126,7 +126,7 @@ void KonsoleMenu::initialize()
exec = KRun::binaryName(exec, false);
exec = KShell::tildeExpand(exec);
- QString pexec = KGlobal::dirs()->findExe(exec);
+ TQString pexec = KGlobal::dirs()->findExe(exec);
if (text.isEmpty() ||
conf.readEntry("Type") != "KonsoleApplication" ||
(!exec.isEmpty() && pexec.isEmpty()))
@@ -135,7 +135,7 @@ void KonsoleMenu::initialize()
}
insertItemSorted(this, SmallIconSet(conf.readEntry("Icon", "konsole")),
text, id++);
- QFileInfo fi(*it);
+ TQFileInfo fi(*it);
sessionList.append(fi.baseName(true));
if (id == 2)
@@ -150,27 +150,27 @@ void KonsoleMenu::initialize()
insertItem(SmallIconSet("keditbookmarks"),
i18n("New Session at Bookmark"), m_bookmarksSession);
connect(m_bookmarkHandlerSession,
- SIGNAL(openURL(const QString&, const QString&)),
- SLOT(newSession(const QString&, const QString&)));
+ TQT_SIGNAL(openURL(const TQString&, const TQString&)),
+ TQT_SLOT(newSession(const TQString&, const TQString&)));
screenList.clear();
- QCString screenDir = getenv("SCREENDIR");
+ TQCString screenDir = getenv("SCREENDIR");
if (screenDir.isEmpty())
{
- screenDir = QFile::encodeName(QDir::homeDirPath()) + "/.screen/";
+ screenDir = TQFile::encodeName(TQDir::homeDirPath()) + "/.screen/";
}
- QStringList sessions;
- // Can't use QDir as it doesn't support FIFOs :(
+ TQStringList sessions;
+ // Can't use TQDir as it doesn't support FIFOs :(
DIR *dir = opendir(screenDir);
if (dir)
{
struct dirent *entry;
while ((entry = readdir(dir)))
{
- QCString path = screenDir + "/" + entry->d_name;
+ TQCString path = screenDir + "/" + entry->d_name;
struct stat st;
if (stat(path, &st) != 0)
{
@@ -182,7 +182,7 @@ void KonsoleMenu::initialize()
(fd = open(path, O_WRONLY | O_NONBLOCK)) != -1)
{
::close(fd);
- screenList.append(QFile::decodeName(entry->d_name));
+ screenList.append(TQFile::decodeName(entry->d_name));
insertItem(SmallIconSet("konsole"),
i18n("Screen is a program controlling screens!",
"Screen at %1").arg(entry->d_name), id);
@@ -197,16 +197,16 @@ void KonsoleMenu::initialize()
delete m_profileMenu;
m_profileMenu = new KPopupMenu(this);
- QStringList profiles = KGlobal::dirs()->findAllResources("data",
+ TQStringList profiles = KGlobal::dirs()->findAllResources("data",
"konsole/profiles/*",
false, true );
m_profiles.resize(profiles.count());
- QStringList::ConstIterator pEnd = profiles.end();
- for (QStringList::ConstIterator pIt = profiles.begin(); pIt != pEnd; ++pIt)
+ TQStringList::ConstIterator pEnd = profiles.end();
+ for (TQStringList::ConstIterator pIt = profiles.begin(); pIt != pEnd; ++pIt)
{
- QFileInfo info(*pIt);
- QString profileName = KIO::decodeFileName(info.baseName());
- QString niceName = profileName;
+ TQFileInfo info(*pIt);
+ TQString profileName = KIO::decodeFileName(info.baseName());
+ TQString niceName = profileName;
KSimpleConfig cfg(*pIt, true);
if (cfg.hasGroup("Profile"))
{
@@ -229,11 +229,11 @@ void KonsoleMenu::initialize()
// we don't have any profiles, disable the menu
setItemEnabled(profileID, false);
}
- connect(m_profileMenu, SIGNAL(activated(int)), SLOT(launchProfile(int)));
+ connect(m_profileMenu, TQT_SIGNAL(activated(int)), TQT_SLOT(launchProfile(int)));
insertSeparator();
insertItem(SmallIconSet("reload"),
- i18n("Reload Sessions"), this, SLOT(reinitialize()));
+ i18n("Reload Sessions"), this, TQT_SLOT(reinitialize()));
}
void KonsoleMenu::slotExec(int id)
@@ -245,7 +245,7 @@ void KonsoleMenu::slotExec(int id)
--id;
kapp->propagateSessionManager();
- QStringList args;
+ TQStringList args;
if (static_cast<unsigned int>(id) < sessionList.count())
{
args << "--type";
@@ -271,7 +271,7 @@ void KonsoleMenu::launchProfile(int id)
--id;
// this is a session, not a bookmark, so execute that instead
- QStringList args;
+ TQStringList args;
args << "--profile" << m_profiles[id];
kapp->kdeinitExec("konsole", args);
}
@@ -283,9 +283,9 @@ KURL KonsoleMenu::baseURL() const
return url;
}
-void KonsoleMenu::newSession(const QString& sURL, const QString& title)
+void KonsoleMenu::newSession(const TQString& sURL, const TQString& title)
{
- QStringList args;
+ TQStringList args;
KURL url = KURL(sURL);
if ((url.protocol() == "file") && (url.hasPath()))
@@ -297,8 +297,8 @@ void KonsoleMenu::newSession(const QString& sURL, const QString& title)
}
else if ((!url.protocol().isEmpty()) && (url.hasHost()))
{
- QString protocol = url.protocol();
- QString host = url.host();
+ TQString protocol = url.protocol();
+ TQString host = url.host();
args << "-T" << title;
args << "-e" << protocol.latin1(); /* argv[0] == command to run. */
if (url.hasUser()) {
diff --git a/kicker/menuext/konsole/konsolebookmarkmenu.cpp b/kicker/menuext/konsole/konsolebookmarkmenu.cpp
index b10d26c40..1a31fe55c 100644
--- a/kicker/menuext/konsole/konsolebookmarkmenu.cpp
+++ b/kicker/menuext/konsole/konsolebookmarkmenu.cpp
@@ -1,7 +1,7 @@
#include <stdio.h>
#include <stdlib.h>
-#include <qtextstream.h>
+#include <tqtextstream.h>
#include <kbookmarkimporter.h>
#include <kmimetype.h>
@@ -14,7 +14,7 @@
#include "konsolebookmarkmenu.h"
#include "konsolebookmarkhandler.h"
-#include <qfile.h>
+#include <tqfile.h>
#include <kaction.h>
#include <klocale.h>
@@ -23,7 +23,7 @@
KonsoleBookmarkMenu::KonsoleBookmarkMenu( KBookmarkManager* mgr,
KonsoleBookmarkHandler * _owner, KPopupMenu * _parentMenu,
KActionCollection *collec, bool _isRoot, bool _add,
- const QString & parentAddress )
+ const TQString & parentAddress )
: KBookmarkMenu( mgr, _owner, _parentMenu, collec, _isRoot, _add,
parentAddress),
m_kOwner(_owner)
@@ -31,14 +31,14 @@ KonsoleBookmarkMenu::KonsoleBookmarkMenu( KBookmarkManager* mgr,
/*
* First, we disconnect KBookmarkMenu::slotAboutToShow()
* Then, we connect KonsoleBookmarkMenu::slotAboutToShow().
* They are named differently because the SLOT() macro thinks we want
* KonsoleBookmarkMenu::KBookmarkMenu::slotAboutToShow()
* Could this be solved if slotAboutToShow() is virtual in KBookmarMenu?
*/
- disconnect( _parentMenu, SIGNAL( aboutToShow() ), this,
- SLOT( slotAboutToShow() ) );
- connect( _parentMenu, SIGNAL( aboutToShow() ),
- SLOT( slotAboutToShow2() ) );
+ disconnect( _parentMenu, TQT_SIGNAL( aboutToShow() ), this,
+ TQT_SLOT( slotAboutToShow() ) );
+ connect( _parentMenu, TQT_SIGNAL( aboutToShow() ),
+ TQT_SLOT( slotAboutToShow2() ) );
}
/*
@@ -64,7 +64,7 @@ void KonsoleBookmarkMenu::refill()
{
//kdDebug(1203) << "KBookmarkMenu::refill()" << endl;
m_lstSubMenus.clear();
- QPtrListIterator<KAction> it( m_actions );
+ TQPtrListIterator<KAction> it( m_actions );
for (; it.current(); ++it )
it.current()->unplug( m_parentMenu );
m_parentMenu->clear();
@@ -86,7 +86,7 @@ void KonsoleBookmarkMenu::fillBookmarkMenu()
addNewFolder();
if ( m_pManager->showNSBookmarks()
- && QFile::exists( KNSBookmarkImporter::netscapeBookmarksFile() ) )
+ && TQFile::exists( KNSBookmarkImporter::netscapeBookmarksFile() ) )
{
m_parentMenu->insertSeparator();
@@ -98,10 +98,10 @@ void KonsoleBookmarkMenu::fillBookmarkMenu()
KonsoleBookmarkMenu *subMenu = new KonsoleBookmarkMenu( m_pManager,
m_kOwner, actionMenu->popupMenu(),
m_actionCollection, false,
- m_bAddBookmark, QString::null );
+ m_bAddBookmark, TQString::null );
m_lstSubMenus.append(subMenu);
- connect( actionMenu->popupMenu(), SIGNAL(aboutToShow()), subMenu,
- SLOT(slotNSLoad()));
+ connect( actionMenu->popupMenu(), TQT_SIGNAL(aboutToShow()), subMenu,
+ TQT_SLOT(slotNSLoad()));
}
}
@@ -111,7 +111,7 @@ void KonsoleBookmarkMenu::fillBookmarkMenu()
for ( KBookmark bm = parentBookmark.first(); !bm.isNull();
bm = parentBookmark.next(bm) )
{
- QString text = bm.text();
+ TQString text = bm.text();
text.replace( '&', "&&" );
if ( !separatorInserted && m_bIsRoot) { // inserted before the first konq bookmark, to avoid the separator if no konq bookmark
m_parentMenu->insertSeparator();
@@ -128,7 +128,7 @@ void KonsoleBookmarkMenu::fillBookmarkMenu()
// kdDebug(1203) << "Creating URL bookmark menu item for " << bm.text() << endl;
// create a normal URL item, with ID as a name
KAction * action = new KAction( text, bm.icon(), 0,
- this, SLOT( slotBookmarkSelected() ),
+ this, TQT_SLOT( slotBookmarkSelected() ),
m_actionCollection, bm.url().url().utf8() );
action->setStatusText( bm.url().prettyURL() );
@@ -163,21 +163,21 @@ void KonsoleBookmarkMenu::fillBookmarkMenu()
void KonsoleBookmarkMenu::slotBookmarkSelected()
{
KAction * a;
- QString b;
+ TQString b;
if ( !m_pOwner ) return; // this view doesn't handle bookmarks...
a = (KAction*)sender();
b = a->text();
- m_kOwner->openBookmarkURL( QString::fromUtf8(sender()->name()), /* URL */
+ m_kOwner->openBookmarkURL( TQString::fromUtf8(sender()->name()), /* URL */
( (KAction *)sender() )->text() /* Title */ );
}
void KonsoleBookmarkMenu::slotNSBookmarkSelected()
{
KAction *a;
- QString b;
+ TQString b;
- QString link(sender()->name()+8);
+ TQString link(sender()->name()+8);
a = (KAction*)sender();
b = a->text();
m_kOwner->openBookmarkURL( link, /*URL */
@@ -31,14 +31,14 @@ KonsoleBookmarkMenu::KonsoleBookmarkMenu( KBookmarkManager* mgr,
* First, we disconnect KBookmarkMenu::slotAboutToShow()
* Then, we connect KonsoleBookmarkMenu::slotAboutToShow().
- * They are named differently because the SLOT() macro thinks we want
+ * They are named differently because the TQT_SLOT() macro thinks we want
* KonsoleBookmarkMenu::KBookmarkMenu::slotAboutToShow()
* Could this be solved if slotAboutToShow() is virtual in KBookmarMenu?